summaryrefslogtreecommitdiff
path: root/tests/core/iconv.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/core/iconv.c')
-rw-r--r--tests/core/iconv.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/tests/core/iconv.c b/tests/core/iconv.c
index 498094bdb..af1b4eabf 100644
--- a/tests/core/iconv.c
+++ b/tests/core/iconv.c
@@ -1,8 +1,8 @@
#include "clar_libgit2.h"
-#include "path.h"
+#include "fs_path.h"
#ifdef GIT_USE_ICONV
-static git_path_iconv_t ic;
+static git_fs_path_iconv_t ic;
static char *nfc = "\xC3\x85\x73\x74\x72\xC3\xB6\x6D";
static char *nfd = "\x41\xCC\x8A\x73\x74\x72\x6F\xCC\x88\x6D";
#endif
@@ -10,14 +10,14 @@ static char *nfd = "\x41\xCC\x8A\x73\x74\x72\x6F\xCC\x88\x6D";
void test_core_iconv__initialize(void)
{
#ifdef GIT_USE_ICONV
- cl_git_pass(git_path_iconv_init_precompose(&ic));
+ cl_git_pass(git_fs_path_iconv_init_precompose(&ic));
#endif
}
void test_core_iconv__cleanup(void)
{
#ifdef GIT_USE_ICONV
- git_path_iconv_clear(&ic);
+ git_fs_path_iconv_clear(&ic);
#endif
}
@@ -27,7 +27,7 @@ void test_core_iconv__unchanged(void)
const char *data = "Ascii data", *original = data;
size_t datalen = strlen(data);
- cl_git_pass(git_path_iconv(&ic, &data, &datalen));
+ cl_git_pass(git_fs_path_iconv(&ic, &data, &datalen));
GIT_UNUSED(datalen);
/* There are no high bits set, so this should leave data untouched */
@@ -42,7 +42,7 @@ void test_core_iconv__decomposed_to_precomposed(void)
size_t datalen, nfdlen = strlen(nfd);
datalen = nfdlen;
- cl_git_pass(git_path_iconv(&ic, &data, &datalen));
+ cl_git_pass(git_fs_path_iconv(&ic, &data, &datalen));
GIT_UNUSED(datalen);
/* The decomposed nfd string should be transformed to the nfc form
@@ -50,13 +50,13 @@ void test_core_iconv__decomposed_to_precomposed(void)
*/
cl_assert_equal_s(nfc, data);
/* should be able to do it multiple times with the same git_path_iconv_t */
data = nfd; datalen = nfdlen;
- cl_git_pass(git_path_iconv(&ic, &data, &datalen));
+ cl_git_pass(git_fs_path_iconv(&ic, &data, &datalen));
cl_assert_equal_s(nfc, data);
data = nfd; datalen = nfdlen;
- cl_git_pass(git_path_iconv(&ic, &data, &datalen));
+ cl_git_pass(git_fs_path_iconv(&ic, &data, &datalen));
cl_assert_equal_s(nfc, data);
#endif
}
@@ -67,7 +67,7 @@ void test_core_iconv__precomposed_is_unmodified(void)
const char *data = nfc;
size_t datalen = strlen(nfc);
- cl_git_pass(git_path_iconv(&ic, &data, &datalen));
+ cl_git_pass(git_fs_path_iconv(&ic, &data, &datalen));
GIT_UNUSED(datalen);
/* data is already in precomposed form, so even though some bytes have
@@ -50,13 +50,13 @@ void test_core_iconv__decomposed_to_precomposed(void)
*/
cl_assert_equal_s(nfc, data);
- /* should be able to do it multiple times with the same git_path_iconv_t */
+ /* should be able to do it multiple times with the same git_fs_path_iconv_t */
data = nfd; datalen = nfdlen;